@@ -30,10 +30,14 @@ import shutil
 from os.path import splitext
 
 from . import image
-from .settings import get_thumb
+from .settings import get_thumb, Status
 from .utils import call_subprocess
 
 
+class SubprocessException(Exception):
+    pass
+
+
 def check_subprocess(cmd, source, outname):
     """Run the command to resize the video and remove the output file if the
     processing fails.
@@ -44,15 +48,17 @@ def check_subprocess(cmd, source, outname):
         returncode, stdout, stderr = call_subprocess(cmd)
     except KeyboardInterrupt:
         logger.debug('Process terminated, removing file %s', outname)
-        os.remove(outname)
+        if os.path.isfile(outname):
+            os.remove(outname)
         raise
 
     if returncode:
-        logger.error('Failed to process ' + source)
         logger.debug('STDOUT:\n %s', stdout)
         logger.debug('STDERR:\n %s', stderr)
-        logger.debug('Process failed, removing file %s', outname)
-        os.remove(outname)
+        if os.path.isfile(outname):
+            logger.debug('Removing file %s', outname)
+            os.remove(outname)
+        raise SubprocessException('Failed to process ' + source)
 
 
 def video_size(source):
@@ -127,7 +133,11 @@ def generate_thumbnail(source, outname, box, fit=True, options=None):
     cmd = ['ffmpeg', '-i', source, '-an', '-r', '1',
            '-vframes', '1', '-y', tmpfile]
     logger.debug('Create thumbnail for video: %s', ' '.join(cmd))
-    check_subprocess(cmd, source, outname)
+
+    try:
+        check_subprocess(cmd, source, outname)
+    except Exception:
+        return
 
     # use the generate_thumbnail function from sigal.image
     image.generate_thumbnail(tmpfile, outname, box, fit, options)
@@ -142,11 +152,19 @@ def process_video(filepath, outpath, settings):
     basename = splitext(filename)[0]
     outname = os.path.join(outpath, basename + '.webm')
 
-    generate_video(filepath, outname, settings['video_size'],
-                   options=settings['webm_options'])
+    try:
+        generate_video(filepath, outname, settings['video_size'],
+                       options=settings['webm_options'])
+    except Exception:
+        return Status.FAILURE
 
     if settings['make_thumbs']:
         thumb_name = os.path.join(outpath, get_thumb(settings, filename))
-        generate_thumbnail(
-            outname, thumb_name, settings['thumb_size'],
-            fit=settings['thumb_fit'], options=settings['jpg_options'])
+        try:
+            generate_thumbnail(
+                outname, thumb_name, settings['thumb_size'],
+                fit=settings['thumb_fit'], options=settings['jpg_options'])
+        except Exception:
+            return Status.FAILURE
+
+    return Status.SUCCESS
